@@ -54,6 +54,7 @@ class CLI(cl1.CLI):
 				"        --forced":"Enable forced mode.",
 				"Mounts:":"*chapter*",
 				"    --mount <alias>:<remote> <path>":"Mount a remote directory.",
+				"    --sync <alias>:<remote> <path>":"Synchronize a remote & local directory (similair to --mount except it never unmounts on neither sides).",
 				"    --unmount <path>":"Unmount a mounted remote directory.",
 				"        --sudo":"Root permission required.",
 				"        --forced":"Enable forced mode.",
@@ -64,9 +65,11 @@ class CLI(cl1.CLI):
 				"Daemons:":"*chapter*",
 				"    --start-daemon <alias>:<remote> <path>":"Start a ssync daemon manually.",
 				"    --stop-daemon <path>":"Stop a ssync daemon.",
+				"    --list-daemons":"List all daemons & their status.",
 				"Basic:":"*chapter*",
 				"    --kill <identifier>":"Kill all ssh processes that include the identifier.",
 				"    --config":"Edit the ssht00ls configuration file (nano).",
+				"    --reset-cache":"Reset the cache directory.",
 				"    --version":"Show the ssht00ls version.",
 				"    -h / --help":"Show the documentation.",
 			},
@@ -74,7 +77,10 @@ class CLI(cl1.CLI):
 				"-j / --json":"Print the response in json format.",
 				"--non-interative":"Disable interactive mode.",
 				"--no-checks":"Disable the default checks.",
-				"--log-level 0":"Overwrite the default log levels.",
+				"--log-level <int>":"Overwrite the default log levels.",
+				"--timeout <int>":"Overwrite the default timeout integer value (10)",
+				"--reattempts <int>":"Overwrite the default reconnects integer value (3).",
+				"--daemon-sleeptime <float>":"Overwrite the default daemon sleeptime float value (0.25).",
 			},
 			notes={
 				"Include config file":"Specify the $SSHT00LS_CONFIG environment variable to use a different ssht00ls config file.",
@@ -110,11 +116,20 @@ class CLI(cl1.CLI):
 
 		# kill ssh processes.
 		elif self.arguments.present('--kill'):
-			response = ssht00ls.utils.kill_ssh(
+			response = ssht00ls.ssh.utils.kill(
 				identifier=self.arguments.get("--kill"), 
 				sudo=self.arguments.present("--sudo"),)
 			self.stop(response=response, json=JSON)
 
+		# reset cache.
+		elif self.arguments.present('--reset-cache'):
+			path = f"{HOME}/.{ALIAS}/.cache/"
+			os.system(f"rm -fr {path}")
+			if os.path.exists(path):
+				self.stop(error=f"Failed to reset cache {path}.", json=JSON)
+			else:
+				self.stop(message=f"Successfully resetted cache {path}.", json=JSON)
+
 		#
 		# ALIASES
 		#
@@ -314,6 +329,8 @@ class CLI(cl1.CLI):
 					},
 					json=JSON,)
 			alias,remote = remote.split(":")
+			remote = syst3m.env.fill(remote)
+			path = syst3m.env.fill(path)
 			exclude = None
 			if self.arguments.present("--exclude"): 
 				exclude = self.arguments.get("--exclude", chapter="push & pull", mode="--pull").split(",")
@@ -343,6 +360,8 @@ class CLI(cl1.CLI):
 					},
 					json=JSON,)
 			alias,remote = remote.split(":")
+			remote = syst3m.env.fill(remote)
+			path = syst3m.env.fill(path)
 			exclude = None
 			if self.arguments.present("--exclude"): 
 				exclude = self.arguments.get("--exclude", chapter="push & pull", mode="--push").split(",")
@@ -376,6 +395,8 @@ class CLI(cl1.CLI):
 					},
 					json=JSON,)
 			alias,remote = remote.split(":")
+			remote = syst3m.env.fill(remote)
+			path = syst3m.env.fill(path)
 			response = ssht00ls.ssync.mount(
 				alias=alias, 
 				remote=remote, 
@@ -383,6 +404,30 @@ class CLI(cl1.CLI):
 				forced=self.arguments.present("--forced"), )
 			self.stop(response=response, json=JSON)
 
+		# sync.
+		elif self.arguments.present('--sync'):
+			remote = self.arguments.get("--sync", index=1, chapter="mounts", mode="--sync", notes={})
+			path = self.arguments.get("--sync", index=2, chapter="mounts", mode="--sync", notes={})
+			if ":" not in remote:
+				self.docs(
+					error=f"Invalid <alias>:<remote> <path>.", 
+					chapter="mounts", 
+					mode="--sync", 
+					notes={
+						"<alias>:<path>":"Pack the alias & tuple together as one argument in the following format [<alias>:<path>]."
+					},
+					json=JSON,)
+			alias,remote = remote.split(":")
+			remote = syst3m.env.fill(remote)
+			path = syst3m.env.fill(path)
+			response = ssht00ls.ssync.mount(
+				alias=alias, 
+				remote=remote, 
+				path=path,
+				forced=self.arguments.present("--forced"), 
+				mode="sync",)
+			self.stop(response=response, json=JSON)
+
 		# unmount.
 		elif self.arguments.present('--unmount'):
 			path = self.arguments.get("--unmount", index=1, chapter="mounts", mode="--unmount")
@@ -397,8 +442,10 @@ class CLI(cl1.CLI):
 			index = self.arguments.get("--index", chapter="mounts", mode="--index")
 			if ":" in index:
 				alias,remote = index.split(":")
+				path = syst3m.env.fill(path)
 				response = ssht00ls.ssync.index(path=remote, alias=alias)
 			else:
+				path = syst3m.env.fill(path)
 				response = ssht00ls.ssync.index(path=index)
 			self.stop(response=response, json=JSON)
 
@@ -420,14 +467,34 @@ class CLI(cl1.CLI):
 					},
 					json=JSON,)
 			alias,remote = remote.split(":")
+			remote = syst3m.env.fill(remote)
+			path = syst3m.env.fill(path)
 			response = ssht00ls.ssync.daemon(alias=alias, remote=remote, path=path)
 			self.stop(response=response, json=JSON)
 
 		# stop daemon.
 		elif self.arguments.present('--stop-daemon'):
-			path = self.arguments.get("--stop-daemon", index=1, chapter="daemon", mode="--stop-daemon")
-			response = ssht00ls.ssync.stop_daemon(path)
-			self.stop(response=response, json=JSON)
+			c = 0
+			for path in self.arguments.get("--stop-daemon", index=1, chapter="daemon", mode="--stop-daemon", format=list):
+				response = ssht00ls.ssync.daemons.stop(path)
+				if not response["success"]:
+					self.stop(response=response, json=JSON)
+					c += 1
+			if c > 0:
+				self.stop(message=f"Successfully stopped {c} daemon(s).", json=JSON)
+			else:
+				self.stop(error="No daemons found.", json=JSON)
+
+		# list daemons.
+		elif self.arguments.present('--list-daemons'):
+			
+			daemons = ssht00ls.ssync.daemons.status()
+			if len(daemons) == 0:
+				self.stop(message=f"There are no active daemons.", json=JSON)
+			print("Daemons:")
+			for path, status in daemons.items():
+				print(f" * {path}: {status}")
+			self.stop(message=f"Successfully listed {len(daemons)} daemon(s).", json=JSON)
 
 		# invalid.
 		else: self.invalid()
