@@ -5,6 +5,7 @@
 from ssht00ls.classes.config import *
 from ssht00ls.classes import utils
 from ssht00ls.classes.smart_cards import smart_cards
+from ssht00ls.classes.ssh import ssh
 
 # the ssh agent object class.
 class Agent(object):
@@ -45,7 +46,7 @@ class Agent(object):
 
 		# set agent.
 		if INTERACTIVE:
-			utils.ssh_agent()
+			ssh.utils.ssh_agent()
 		#if self.SSH_AUTH_SOCK == None or self.SSH_AGENT_PID == None:
 		#	utils.__execute_script__("pkill -9 -f ssh-agent")
 		#	output = subprocess.check_output(["ssh-agent"]).decode()
@@ -91,26 +92,24 @@ class Agent(object):
 
 		# initialize.
 		path = path.replace("//", "/")
-		response = utils.__default_response__()
-		success, response = utils.__check_parameters__(empty_value=None, parameters={
+		response = r3sponse.check_parameters(empty_value=None, parameters={
 			"path":path
 		})
-		if not success: return response
+		if not response["success"]: return response
 		if smart_card:
-			success, response = utils.__check_parameters__(empty_value=None, parameters={
+			response = r3sponse.check_parameters(empty_value=None, parameters={
 				"pin":pin
 			})
-			if not success: return response
+			if not response["success"]: return response
 		else:
 			if not os.path.exists(path):
-				response["error"] = f"Key path [{path}] does not exist."
-				return response
+				return r3sponse.error_response(f"Key path [{path}] does not exist.")
 
 		# check agent connection.
 		output = utils.__execute__(["ssh-add", "-L"])
 		if "Failed to communicate" in output or "agent refused operation" in output or "Error connecting to agent" in output or "Connection refused" in output:
 			if reattempt:
-				utils.ssh_agent()
+				ssh.utils.ssh_agent()
 				return self.add(
 					# the keys path.
 					path=path,
@@ -129,7 +128,6 @@ class Agent(object):
 				return r3sponse.error_response("Failed to communicate with the ssh-agent. Try logging out the current system user & logging back in (or execute [$ eval `ssh-agent`]).")
 
 		# with passphrase.
-		response = utils.__default_response__()
 		if smart_card or passphrase != None:
 			#self.initialize()
 			if smart_card:
@@ -194,7 +192,7 @@ class Agent(object):
 				return r3sponse.error_response("Provided an incorrect pin code.")
 			elif "Failed to communicate" in output or "agent refused operation" in output or "Error connecting to agent" in output or "Connection refused" in output:
 				if reattempt:
-					utils.ssh_agent()
+					ssh.utils.ssh_agent()
 					return self.add(
 						# the keys path.
 						path=path,
@@ -222,8 +220,7 @@ class Agent(object):
 			"""try:
 				spawn.expect(pexpect.EOF, timeout=timeout)
 			except pexpect.ExceptionPexpect as epe:
-				response["error"] = f"Failed to add key [{path}] to the ssh agent #3."
-				return response"""
+				return r3sponse.error_response(f"Failed to add key [{path}] to the ssh agent #3.")"""
 
 		# without pass.
 		else:
@@ -240,70 +237,61 @@ class Agent(object):
 		#
 	def delete(self):
 
-		# initialize.
-		response = utils.__default_response__()
-
 		# delete keys.
 		output = utils.__execute__(command=["ssh-add", "-D"])
 
 		# check success.
 		if "Could not open a connection to your authentication agent." in output:
-			response["error"] = "Failed to communicate with the ssh-agent."
-			return response
+			return r3sponse.error_response("Failed to communicate with the ssh-agent.")
 		elif "All identities removed." in output: 
-			response["success"] = True
-			response["message"] = f"Successfully removed all keys from the ssh agent."
-			return response
+			return r3sponse.success_response(f"Successfully removed all keys from the ssh agent.")
 		else: 
-			response["message"] = f"Failed to remove all keys from the ssh agent."
-			return response
+			return r3sponse.error_response(f"Failed to remove all keys from the ssh agent.")
 
 		#
 	def list(self):
 		# initialize.
-		response = utils.__default_response__()
+		keys = []
 
 		# list keys.
 		output = utils.__execute__(command=["ssh-add", "-L"], return_format="array")
 		if "Failed to communicate" in output:
-			response["error"] = "Failed to communicate with the ssh-agent."
-			return response
+			return r3sponse.error_response("Failed to communicate with the ssh-agent.")
 		elif "The agent has no identities." in output:
-			response["keys"] = []
+			keys = []
 		else:
-			response["keys"] = output
-		return response
+			keys = output
+		return r3sponse.success_response(f"Successfully listed the agent's keys.", {
+			"keys":keys,
+		})
 
 		#
 	def check(self, public_key=None, raw=False):
-		
-		# initialize.
-		response = utils.__default_response__()		
+
 
 		# params.
-		success, response = utils.__check_parameter__(public_key, "public_key", None)
-		if not success: return response
+		response = r3sponse.check_parameters({
+			"public_key":public_key
+		})
+		if not response["success"]: return response
 
 		# checks.
 		if not raw and not os.path.exists(public_key):
-			response["error"] = f"Public key path [{public_key}] does not exist."
-			return response
+			return r3sponse.error_response(f"Public key path [{public_key}] does not exist.")
 
 		# load public key.
 		if not raw:
 			try:
 				public_key = utils.__load_file__(public_key)
 			except:
-				response["error"] = f"Failed to load public key path [{public_key}]."
-				return response
+				return r3sponse.error_response(f"Failed to load public key path [{public_key}].")
 
 		# retrieve id from public key.
 		"""
 		try:
 			public_key_id = public_key.split("[#id:")[1].split("]")[0]
 		except IndexError:
-			response["error"] = f"Public key [{public_key}] does not contain any id."
-			return response
+			return r3sponse.error_response(f"Public key [{public_key}] does not contain any id.")
 
 		# list.
 		response = self.list()
@@ -328,20 +316,14 @@ class Agent(object):
 				break
 
 		# success.
-		response = utils.__default_response__()		
 		if success:
-			response["success"] = True
-			response["message"] = f"Public key [{public_key}] is added to the ssh agent."
+			return r3sponse.success_response(f"Public key [{public_key}] is added to the ssh agent.")
 		else:
-			response["error"] = f"Public key [{public_key}] is not added to the ssh agent."
-		return response
+			return r3sponse.error_response(f"Public key [{public_key}] is not added to the ssh agent.")
 
 		#
 	def initialize(self):
 
-		# initialize.
-		response = utils.__default_response__()
-
 		# check communication.
 		output = utils.__execute__(command=["ssh-add", "-l"])
 		#print("DEBUG; initialize output ssh-add -l:",output)
@@ -350,23 +332,18 @@ class Agent(object):
 				l = subprocess.check_output(['eval', '"$(ssh-agent)"'], shell=True).decode()
 				output = utils.__execute__(command=["ssh-add", "-l"])
 				if "Failed to communicate" in output or "Error connecting to agent" in output:
-					response["error"] = "Failed to communicate with the ssh-agent."
-					return response
+					return r3sponse.error_response("Failed to communicate with the ssh-agent.")
 				else:
 					output = utils.__execute__(command=["ssh-add", "-l"])
 					if "Failed to communicate" in output or "Error connecting to agent" in output:
-						response["error"] = "Failed to communicate with the ssh-agent."
-						return response
+						return r3sponse.error_response("Failed to communicate with the ssh-agent.")
 			else:
 				output = utils.__execute__(command=["ssh-add", "-l"])
 				if "Failed to communicate" in output or "Error connecting to agent" in output:
-					response["error"] = "Failed to communicate with the ssh-agent."
-					return response
+					return r3sponse.error_response("Failed to communicate with the ssh-agent.")
 
 		# success.
-		response["success"] = True
-		response["message"] = f"Successfully initialized the ssh agent."
-		return response
+		return r3sponse.success_response(f"Successfully initialized the ssh agent.")
 
 # Initialized objects.
 agent = Agent()
