@@ -111,6 +111,8 @@ class Aliases(object):
 		pin=None,
 		# save to configuration.
 		save=True,
+		# do checks.
+		checks=True,
 		# serialized all parameters as dict, except: [save].
 		serialized={},
 	):
@@ -141,7 +143,7 @@ class Aliases(object):
 			except KeyError: alias = None
 
 		# checks.
-		success, response = utils.__check_parameters__({
+		response = r3sponse.check_parameters({
 			"alias":alias,
 			"username":username,
 			"public_ip":public_ip,
@@ -151,21 +153,22 @@ class Aliases(object):
 			"private_key":private_key,
 			"public_key":public_key,
 		}, empty_value=None)
-		if not success: return response
+		if not response["success"]: return response
 		if smart_card:
-			success, response = utils.__check_parameters__({
+			response = r3sponse.check_parameters({
 				"pin":pin,
 			}, empty_value=None)
-			if not success: return response
+			if not response["success"]: return response
 		else:
-			success, response = utils.__check_parameters__({
+			response = r3sponse.check_parameters({
 				"passphrase":passphrase,
 			}, empty_value=None)
-			if not success: return response
+			if not response["success"]: return response
 
 		# duplicate.
-		response = self.check_duplicate(alias)
-		if not response["success"]: return response
+		if checks:
+			response = self.check_duplicate(alias)
+			if not response["success"]: return response
 
 		# keys.
 		private_key = syst3m.env.fill(private_key)
@@ -176,7 +179,7 @@ class Aliases(object):
 			return r3sponse.error_response(f"Public key {public_key} does not exist.")
 
 		# info.
-		json_config = {}
+		json_config, config = {}, ""
 		if NETWORK_INFO["public_ip"] == public_ip:
 			ip = private_ip
 			port = private_port
@@ -256,9 +259,9 @@ class Aliases(object):
 				if not cl1.argument_present("--non-interactive"):
 					passphrase = None
 					if checked["smart_card"] and checked["pin"] in [None, "", "none", "None"]:
-						passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['key']}:")
+						passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['private_key']}:")
 					elif checked["passphrase"] in [None, "", "none", "None"]:
-						passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['key']}:")
+						passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['private_key']}:")
 					if checked["smart_card"]:
 						response = agent.check(public_key=checked["public_key"], raw=True)
 					else:
@@ -280,7 +283,7 @@ class Aliases(object):
 						else:
 							CONFIG["aliases"][alias]["passphrase"] = response.encrypted.decode()
 						CONFIG.save()
-				response = self.create(save=False, serialized=checked)
+				response = self.create(save=False, checks=False, serialized=Files.Dictionary(dictionary=checked).append({"alias":alias}))
 				if not response["success"]: return response
 				aliases += response["str"]
 				c += 1
