@@ -14,7 +14,6 @@ class Installation(object):
 		username=None,
 	):
 		# initialize.
-		response = utils.__default_response__()
 		if username == None: username = OWNER
 		home = f"{HOME_BASE}/{username}/"	
 		sudo = True
@@ -75,9 +74,7 @@ class Installation(object):
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
 
 		# success.
-		response["success"] = True
-		response["message"] = f"Successfully installed ssh for user [{username}]."
-		return response
+		return r3sponse.success_response(f"Successfully installed ssh for user [{username}].")
 
 		#
 	def check_installed(self, 
@@ -86,7 +83,6 @@ class Installation(object):
 	):	
 
 		# initialize.
-		response = utils.__default_response__()
 		if username == None: username = OWNER
 		home = f"{HOME_BASE}/{username}/"	
 		sudo = True
@@ -94,8 +90,7 @@ class Installation(object):
 		# users ssh directory.
 		fp = Formats.FilePath(f"{home}.ssh/")
 		if not fp.exists():
-			response["error"] = f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed."
-			return response
+			return r3sponse.error_response(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
 		else:
 			fp.permission.set(permission=700, sudo=sudo)
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
@@ -103,8 +98,7 @@ class Installation(object):
 		# the ssh config.
 		fp = Formats.FilePath(f"{home}.ssh/config")
 		if not fp.exists():
-			response["error"] = f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed."
-			return response
+			return r3sponse.error_response(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
 		else:
 			fp.permission.set(permission=644, sudo=sudo)
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
@@ -112,8 +106,7 @@ class Installation(object):
 		# the ssh known hosts.
 		fp = Formats.FilePath(f"{home}.ssh/known_hosts")
 		if not fp.exists():
-			response["error"] = f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed."
-			return response
+			return r3sponse.error_response(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
 		else:
 			fp.permission.set(permission=644, sudo=sudo)
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
@@ -121,16 +114,13 @@ class Installation(object):
 		# authorized keys.
 		fp = Formats.FilePath(f"{home}.ssh/authorized_keys")
 		if not fp.exists():
-			response["error"] = f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed."
-			return response
+			return r3sponse.error_response(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
 		else:
 			fp.permission.set(permission=600, sudo=sudo)
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
 
 		# success.
-		response["success"] = True
-		response["message"] = f"SSH is successfully installed for user [{username}]."
-		return response
+		return r3sponse.success_response(f"SSH is successfully installed for user [{username}].")
 			
 # Initialized objects.
 installation = Installation()
